package com.muyu.source.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.source.domain.DataSource;
import com.muyu.source.domain.req.DataSourceQueryReq;
import com.muyu.source.service.DataSourceService;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @ Tool：IntelliJ IDEA
 * @ Author：CHX
 * @ Date：2024-08-20-18:34
 * @ Version：1.0
 * @ Description：数据源控制层
 * @author Lenovo
 */
@Log4j2
@RestController
@RequestMapping("/dataSource")
@Tag(name = "数据源控制层",description = "进行数据源管理，查看等相关操作")
public class DataSourceController extends BaseController {

    /**
     * 数据源业务层
     */
    @Autowired
    private DataSourceService dataSourceService;

    /**
     * 查询数据源的全部数据
     * @return 数据源
     */
    @GetMapping("/getDataSourceList")
    public Result<List<DataSource>> list(){
        List<DataSource> list =dataSourceService.list();
        return Result.success(list);
    }

    /**
     * 根据ID获取数据
     * @param id 数据源ID
     * @return 数据源
     */
    @GetMapping("getDataSourceById/{id}")
    public Result<DataSource> getDataSourceById(@PathVariable("id") Long id){
        DataSource dataSource = dataSourceService.getById(id);
        return Result.success(dataSource);
    }

    /**
     * 查询数据源列表的全部数据
     * @param dataSourceQueryReq 数据源
     * @return 数据源
     */
    @GetMapping("/list")
    public Result<List<DataSource>> list(DataSourceQueryReq dataSourceQueryReq){
        List<DataSource> list =dataSourceService.list(DataSource.queryBuild(dataSourceQueryReq));
        return Result.success(list);
    }

    /**
     * 添加数据源
     * @param dataSource 数据源
     * @return 数据源
     */
    @PostMapping("/insert")
    public Result insert(@RequestBody DataSource dataSource){
        dataSourceService.save(dataSource);
        return Result.success();
    }

    /**
     * 修改数据源
     * @param dataSource 数据源
     * @return 数据源
     */
    @PutMapping("/update")
    public Result update(@RequestBody DataSource dataSource){
        dataSourceService.updateById(dataSource);
        return Result.success();
    }

    /**
     * 删除数据源
     * @param dataSource 数据源
     * @return 数据源
     */
    @DeleteMapping("/delete")
    public Result delete(@RequestBody DataSource dataSource){
        dataSourceService.removeById(dataSource);
        return Result.success();
    }




}
